Usage
maNormNN(mbatch,w=NULL,binWidth=3,binHeight=3,model.nonlins=3,iterations=100,nFolds=10,maplots=FALSE,verbose=FALSE)
Arguments
mbatch
A marrayRaw or marrayNorm batch of arrays.
w
Weights to be assigned to each spot. If provided, it should be a vector with the same length as maNspots(mbatch).
binWidth
Width of the bins in the $X$ direction (spot column) in which the
print tip will be divided in order to account for spatial variation. Max value
is maNsc(mbatch), Min value is 1. However if it is set to a number larger than
maNsc(mbatch)/2 (so less than two bins in $X$ direction) the variable $X$ will not
be used as predictor to estimate the bias.
binHeight
Height of the bins in the $Y$ direction (spot row)in which the
print tip will be divided in order to account for spatial variation. Max value
is maNsr(mbatch), Min value is 1. However if it is set to a number larger than
maNsr(mbatch)/2 (so less than two bins in $Y$ direction) the variable $Y$ will not
be used as predictor to estimate the bias.
model.nonlins
Number of nodes in the hidden layer of the neural network model.
iterations
The number of iterations at which (if not converged) the training of the neural net will be
stopped.
nFolds
Number of cross-validation folds. It represents the number of equal parts in which the data from a
print tip is divided into: the model is trained on nFolds-1 parts and the bias is estimated for one part at the
time. Higher values improve the results but increase the computation time. Ideal values are between 5 and 10.
maplots
If set to "TRUE" will produce a $M-A$ plot for each slide before and after normalization.
verbose
If set to "TRUE" will show the output of the nnet function which is training the neural
network models.